##  Introduction to Shared 360
Shared 360 is a feature provided by Gainsight, a customer success platform. This tool is aimed at enhancing collaboration between SAP LeanIX customers and their Customer Success team. Shared 360 provides a comprehensive overview of customer's interactions with SAP LeanIX, including their usage data, login statistics, support tickets, and more.
As a workspace admin, you can request access to your Shared 360 view through your Customer Success Manager. Once you get access, you can monitor how your organization uses SAP LeanIX and then share these insights with your team.
By using Shared 360, you can:
  * Get a comprehensive overview of your SAP LeanIX account, including metrics for some key features such as fact sheets and reports
  * Assess the adoption of SAP LeanIX by your organization
  * Identify opportunities for improvement and enablement by analyzing key metrics
